<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'Backup vun der Datebank als SQLite an Zeréckspillen',
	'dump_slogan' => 'Backup an Zeréckspillen vun der SPIP-Datebank',
];
